pub async fn read_frame<R: AsyncRead + Unpin>(
r: &mut R,
) -> Result<Frame, CodecError>Expand description
Read one frame, or CodecError::Eof if the stream ends cleanly before the next length prefix.
pub async fn read_frame<R: AsyncRead + Unpin>(
r: &mut R,
) -> Result<Frame, CodecError>Read one frame, or CodecError::Eof if the stream ends cleanly before the next length prefix.